@@ -16,7 +16,7 @@
 # This script will start the datastore server listening on an available socket
 serverpath=.;
 
-CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.7.0.v20110110.jar:org.eclipse.equinox.common_3.6.0.v20110523.jar:org.eclipse.core.filesystem_1.3.100.v20110423-0524.jar:com.ibm.icu.base_4.4.2.v20110208.jar:stubs.jar:lrparser.jar:upcparser.jar:xlcparser.jar:spawner.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v201004271650.jar:$CLASSPATH;
+CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.8.0.v20120521-2346.jar:org.eclipse.equinox.common_3.6.100.v20120522-1841.jar:org.eclipse.core.filesystem_1.3.200.v20120522-2012.jar:com.ibm.icu.base_4.4.2.v20110831.jar:org.eclipse.text_3.5.200.v20120523-1310.jar:stubs.jar:lrparser.jar:upcparser.jar:xlcparser.jar:spawner.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v201004271650.jar:$CLASSPATH;
 LIBPATH=$serverpath:$LIBPATH;
 export serverpath CLASSPATH LIBPATH
 			
